import { type Page, type Locator } from '@playwright/test';
import { ERROR_INCORRECT_EMAIL_PASSWORD } from '../constants/constants';

export class LogInPage {
  readonly page: Page;
  readonly emailInputLocator: Locator
  readonly passwordInputLocator: Locator
  readonly signInButtonLocator: Locator

  public constructor(page: Page) {
    this.page = page;
    this.emailInputLocator = page.getByPlaceholder('Email address')
    this.passwordInputLocator = page.getByPlaceholder('Password')
    this.signInButtonLocator = page.getByRole('button', { name: 'Log in' })
  }
  async visit(site: string) {
    try {
      await this.page.goto(site);
    } catch (error) {
      console.error('Failed to navigate to the site:', error);
      throw error;
    }
  }
  async login(email: string, password: string) {
    try {
      await this.emailInputLocator.fill(email);
      await this.passwordInputLocator.fill(password);
      await this.signInButtonLocator.click();
    } catch (error) {
      console.error('Login failed:', error);
      throw new Error('Login failed');
    }
  }

  async visitForgotPassword(site: string) {
    try {
      await this.page.goto(site);
    } catch (error) {
      console.error('Failed to navigate to the forgot password page:', error);
      throw new error;
    }
  }

  async errorMessageIsValid(): Promise<boolean> {
    try {
      const isVisible = await this.page.locator('.well.well-small.text-error').isVisible();
      if (!isVisible) {
        return false;
      }
      const errorText = await this.page.locator('.well.well-small.text-error').textContent();
      return errorText === ERROR_INCORRECT_EMAIL_PASSWORD;
    } catch (error) {
      console.error('Failed to check error message:', error);
      throw new error;
    }
  }
}

