import { Page, Locator } from "@playwright/test"

export class ViewMyCredentialsPage {

    readonly page: Page
    readonly primaryTitle: Locator
    readonly secondaryTitle: Locator
    readonly typeTitle: Locator
    readonly detailsTitle: Locator
    readonly issuedOnTitle: Locator
    readonly statusTitle: Locator
    readonly viewCredentialButton: Locator


    constructor(page: Page) {
        this.page = page;
        this.primaryTitle = page.getByRole('heading', { name: 'My wallet' });
        this.secondaryTitle = page.getByRole('heading', { name: 'Credential management' });
        this.typeTitle = page.getByRole('link', { name: 'Type' })
        this.detailsTitle = page.getByRole('link', { name: 'Details' })
        this.issuedOnTitle = page.getByRole('link', { name: 'Issued on' })
        this.statusTitle = page.getByRole('link', { name: 'Status' })
        this.viewCredentialButton = page.getByRole('link', { name: '' })

    }
    async getPrimaryTitle() {
        try {
            return await this.primaryTitle.innerText();
        } catch (error) {
            console.error("Failed to get primary title:", error);
            throw error;
        }
    }

    async getSecondaryTitle() {
        try {
            return await this.secondaryTitle.innerText();
        } catch (error) {
            console.error("Failed to get secondary title:", error);
            throw error;
        }
    }


    async getTypeTitle() {
        try {
            return this.typeTitle;
        } catch (error) {
            console.error("Failed to get Type title:", error);
            throw error;
        }
    }

    async getDetailsTitle() {
        try {
            return this.detailsTitle;
        } catch (error) {
            console.error("Failed to get Details title:", error);
            throw error;
        }
    }

    async getIssuedOnTitle() {
        try {
            return this.issuedOnTitle;
        } catch (error) {
            console.error("Failed to get Issue On title:", error);
            throw error;
        }
    }

    async getStatusTitle() {
        try {
            return this.statusTitle;
        } catch (error) {
            console.error("Failed to get Issue On title:", error);
            throw error;
        }
    }


    async orderTableByType() {
        (await this.getTypeTitle()).click();
    }

    async orderTableByIssuedOn() {
        (await this.getIssuedOnTitle()).click();
    }

    async gotoViewEnabledCredentialPage(type: string) {

        // Find the row that has the specified type and status 'Enabled'
        const row = this.page.locator(`tr:has(td:nth-child(1):has-text("${type}"), td:nth-child(4):has-text("Enabled"))`);

        // Check if the row exists
        if (await row.count() > 0) {
            // Find the view credential button within the row and click it
            await row.locator('i.bi.bi-eye').click();
        } else {
            console.log(`No row found with type '${type}' and status 'Enabled'.`);
        }

    }

    async enabledCredentialExistInMyCredentials(type: string): Promise<boolean> {

        // Find the row that has the specified type and status 'Enabled'
        const row = this.page.locator(`tr:has(td:nth-child(1):has-text("${type}"), td:nth-child(4):has-text("Enabled"))`);

        // Check if the row exists
        if (await row.count() > 0) {
            return true;
        } else {
            console.log(`No row found with type '${type}' and status 'Enabled'.`);
            return false;
        }
    }

}